@@ -1,26 +1,28 @@
+from abc import ABC, abstractmethod
 from typing import Dict, List, Optional
 
-from pydantic import validator
+from pydantic import BaseModel, validator
 from pydantic.dataclasses import dataclass
 from typeguard import typechecked
 
 from devinstaller_core import command as c
 from devinstaller_core import exception as e
+from devinstaller_core import utilities as u
+
+ui = u.UserInteraction()
 
 
 @dataclass
 class ModuleInstallInstruction:
-    """The class used to convert `init`, `command` and `config` into objects
-    """
+    """The class used to convert `init`, `command` and `config` into objects"""
 
     cmd: str
     rollback: Optional[str] = None
 
 
 @dataclass
-class ModuleBase:
-    """The class which will be used by all the modules
-    """
+class ModuleBase(ABC):
+    """The class which will be used by all the modules"""
 
     # pylint: disable=too-many-instance-attributes
     name: str
@@ -33,14 +35,33 @@ class ModuleBase:
     after: Optional[str] = None
     constants: Optional[Dict[str, str]] = None
 
+    @validator("alias", pre=True, check_fields=False)
+    @classmethod
+    def alias_validator(cls, alias: Optional[str], values) -> str:
+        """Set the alias if it is not provided."""
+        if alias is None:
+            return values["name"]
+        return alias
+
+    @validator("display", pre=True, check_fields=False)
+    @classmethod
+    def display_validator(cls, display: Optional[str], values) -> str:
+        """Set the display if it is not provided."""
+        if display is None:
+            return values["name"]
+        return display
+
+    @validator("constants", pre=True, check_fields=False)
     @classmethod
-    @validator("constants", pre=True)
     def convert_constant(
         cls, constants: Optional[List[Dict[str, str]]]
     ) -> Dict[str, str]:
+        """Convert incomming dict into dict which can be used for
+        constants replacing.
+        """
         data: Dict[str, str] = {}
         if constants is None:
-            return data
+            return {}
         for i in constants:
             data[i["key"]] = i["value"]
         return data
@@ -50,21 +71,15 @@ class ModuleBase:
             return f"{self.display}"
         return f"{self.display} - {self.description}"
 
+    @abstractmethod
     def install(self) -> None:
-        """Abstract install function for each module to be immplemented
-        """
-        raise NotImplementedError
+        """Abstract install function for each module to be immplemented"""
+        pass
 
+    @abstractmethod
     def uninstall(self) -> None:
-        """Abstract uninstall function for each module to be immplemented
-        """
-        raise NotImplementedError
-
-    def __post_init_post_parse__(self):
-        if self.alias is None:
-            self.alias = self.name
-        if self.display is None:
-            self.display = self.name
+        """Abstract uninstall function for each module to be immplemented"""
+        pass
 
     @classmethod
     @typechecked
@@ -84,7 +99,7 @@ class ModuleBase:
             return None
         for index, inst in enumerate(instructions):
             try:
-                session = c.Command()
+                session = c.SessionSpec()
                 session.run(inst.cmd)
             except e.CommandFailed:
                 rollback_list = instructions[:index]
@@ -113,8 +128,8 @@ class ModuleBase:
         for inst in instructions:
             if inst.rollback is not None:
                 try:
-                    print(f"Rolling back `{inst.cmd}` using `{inst.rollback}`")
-                    session = c.Command()
+                    ui.print(f"Rolling back `{inst.cmd}` using `{inst.rollback}`")
+                    session = c.SessionSpec()
                     session.run(inst.rollback)
                 except e.CommandFailed:
                     raise e.ModuleRollbackFailed
